@@ -967,7 +967,7 @@ class IceServer(TypedDict):
 # Schema related types and interfaces
 PluginConfig = dict[str, Any]
 
-J = TypeVar("J", bound=Union[str, list[str], int, list[int], bool, list[bool], Any])
+J = TypeVar("J", bound=Union[str, list[str], float, list[float], bool, list[bool], Any])
 
 
 class JsonFactorySchema(TypedDict):
@@ -988,9 +988,19 @@ class JsonBaseSchmaWithoutCallbacks(JsonFactorySchema, Generic[J]):
 class JsonBaseSchema(JsonBaseSchmaWithoutCallbacks[J], Generic[J]):
     store: NotRequired[bool]
     onSet: NotRequired[
-        Union[Callable[[Any, Any], Awaitable[Union[None, Any]]], Callable[[Any, Any], Union[None, Any]]]
+        Union[
+            Callable[[Any, Any], None | Any],
+            Callable[[Any, Any], Awaitable[None | Any]],
+            Callable[[Any, Any], Coroutine[Any, Any, None | Any]],
+        ]
+    ]
+    onGet: NotRequired[
+        Union[
+            Callable[..., Union[Any, None]],
+            Callable[..., Awaitable[Union[Any, None]]],
+            Callable[..., Coroutine[Any, Any, Union[Any, None]]],
+        ]
     ]
-    onGet: NotRequired[Union[Callable[[], Awaitable[Union[Any, None]]], Callable[[], Union[Any, None]]]]
 
 
 class JsonStringSchema(TypedDict):
@@ -1006,7 +1016,7 @@ class JsonNumberSchema(TypedDict):
     type: Literal["number"]
     minimum: NotRequired[int]
     maximum: NotRequired[int]
-    step: NotRequired[int]
+    step: NotRequired[float]
 
 
 class JsonBooleanSchema(TypedDict):
@@ -1033,11 +1043,11 @@ class JsonSchemaStringWithoutCallbacks(JsonBaseSchmaWithoutCallbacks[str], JsonS
     pass
 
 
-class JsonSchemaNumber(JsonBaseSchema[int], JsonNumberSchema):
+class JsonSchemaNumber(JsonBaseSchema[float], JsonNumberSchema):
     pass
 
 
-class JsonSchemaNumberWithoutCallbacks(JsonBaseSchmaWithoutCallbacks[int], JsonNumberSchema):
+class JsonSchemaNumberWithoutCallbacks(JsonBaseSchmaWithoutCallbacks[float], JsonNumberSchema):
     pass
 
 
@@ -1057,12 +1067,12 @@ class JsonSchemaEnumWithoutCallbacks(JsonBaseSchmaWithoutCallbacks[Union[str, li
     pass
 
 
-class JsonSchemaArray(JsonBaseSchema[Union[list[str], list[int], list[bool]]], JsonArraySchema):
+class JsonSchemaArray(JsonBaseSchema[Union[list[str], list[float], list[bool]]], JsonArraySchema):
     pass
 
 
 class JsonSchemaArrayWithoutCallbacks(
-    JsonBaseSchmaWithoutCallbacks[Union[list[str], list[int], list[bool]]], JsonArraySchema
+    JsonBaseSchmaWithoutCallbacks[Union[list[str], list[float], list[bool]]], JsonArraySchema
 ):
     pass
 
@@ -1070,13 +1080,21 @@ class JsonSchemaArrayWithoutCallbacks(
 class JsonSchemaButton(JsonFactorySchema):
     type: Literal["button"]
     color: NotRequired[Literal["success", "info", "warn", "danger"]]
-    onSet: Callable[[], Awaitable[None]]
+    onSet: Union[
+        Callable[[Any, Any], None | Any],
+        Callable[[Any, Any], Awaitable[None | Any]],
+        Callable[[Any, Any], Coroutine[Any, Any, None | Any]],
+    ]
 
 
 class JsonSchemaSubmit(JsonFactorySchema):
     type: Literal["submit"]
     color: NotRequired[Literal["success", "info", "warn", "danger"]]
-    onClick: Union[Callable[["FormSubmitResponse"], None], Awaitable[Union["FormSubmitResponse", None]]]
+    onClick: Union[
+        Callable[[Any], "Optional[FormSubmitResponse]"],
+        Callable[[Any], Awaitable["Optional[FormSubmitResponse]"]],
+        Callable[[Any], Coroutine[Any, Any, "Optional[FormSubmitResponse]"]],
+    ]
 
 
 class JsonSchemaStringWithoutCallbacksAndKey(TypedDict):
@@ -1105,10 +1123,10 @@ class JsonSchemaNumberWithoutCallbacksAndKey(TypedDict):
     required: NotRequired[bool]
     readonly: NotRequired[bool]
     placeholder: NotRequired[str]
-    defaultValue: NotRequired[int]
+    defaultValue: NotRequired[float]
     minimum: NotRequired[int]
     maximum: NotRequired[int]
-    step: NotRequired[int]
+    step: NotRequired[float]
 
 
 class JsonSchemaBooleanWithoutCallbacksAndKey(TypedDict):
@@ -1146,7 +1164,7 @@ class JsonSchemaArrayWithoutCallbacksAndKey(TypedDict):
     required: NotRequired[bool]
     readonly: NotRequired[bool]
     placeholder: NotRequired[str]
-    defaultValue: NotRequired[Union[list[str], list[int], list[bool]]]
+    defaultValue: NotRequired[Union[list[str], list[float], list[bool]]]
     opened: NotRequired[bool]
     items: "JsonSchemaWithoutCallbacksAndKey"
 
